@@ -17,7 +17,8 @@ def MSC(input_data):
     OUTPUT
     X_msc [n x k] 
         preprocessed spectra
-    
+    reference [1 x k] 
+        reference spectra
     '''
     
     
