@@ -1,6 +1,6 @@
 from RG.xlsread import *
 from RG.regress import *
-from RG.R2 import *
+from RG.reset import *
 
 from RG.PCA import *
 from RG.PLS import *
@@ -12,13 +12,18 @@ from RG.PCA_ellipse import *
 from RG.ICA import *
 from RG.MCR import *
 
-
 from RG.colorspectra import *
 from RG.axaline import *
 from RG.lags import *
 from RG.DTW import *
 from RG.DTW_batch import *
 
+from RG.correlated_matrix import *
+from RG.pcorrcoef import *
+from RG.R2 import *
+from RG.normplot import *
+
+
 from RG.center import *
 from RG.autoscale import *
 from RG.baseline import *
