@@ -12,7 +12,7 @@ import openpyxl
 
 def xlsread(wb, ws, cell_tl, cell_br):
 
-    wb = openpyxl.load_workbook(wb)
+    wb = openpyxl.load_workbook(wb, data_only = True)
     ws = wb[ws] # Pick worksheet from workbook
     ws = ws[cell_tl:cell_br] 
     
